#!/bin/bash
#

source ${PRODUCTS}/setup
flvr=`ups flavor`
lhapdfdir=${PRODUCTS}/lhapdf/v5_8_4/${flvr}-gcc45
sourcedir=${PRODUCTS}/lhapdf/v5_8_4/source/lhapdf-5.8.4

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc v4_5_1
setup gcc v4_5_1
gccver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.5.1" ]
then
  echo " OK - gcc version is ${gccver}"
else
  echo "ERROR: wrong gcc version ${gccver}"
  exit 1
fi

mkdir -p ${lhapdfdir}/build
if [ ! -d ${lhapdfdir}/build ]
then
   echo "ERROR: failed to create ${lhapdfdir}/build"
   exit 1
fi
cd ${lhapdfdir}/build

set -x

${sourcedir}/configure --prefix=${lhapdfdir} --enable-low-memory --disable-pyext
make 
# make check requires pdfsets, so skip
#make check
make install 

# install example source code by hand
cp -pr ${sourcedir}/examples ${lhapdfdir}/examples
rm -f ${lhapdfdir}/examples/Makefile.*
rm -f ${lhapdfdir}/examples/*.py
cp -p ${lhapdfdir}/build/examples/* ${lhapdfdir}/examples/

set +x

if [ ! -d ${lhapdfdir}/lib ]
then
   echo "ERROR: failed to create ${lhapdfdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# fixing bin/lhapdf-config
mv ${lhapdfdir}/bin/lhapdf-config ${lhapdfdir}/bin/lhapdf-config.bak
cat ${lhapdfdir}/bin/lhapdf-config.bak | sed 's%^prefix=.*$%prefix=${LHAPDF_FQ_DIR}%' > ${lhapdfdir}/bin/lhapdf-config


# this should not complain
   echo "Finished building lhapdf for flavor ${flvr}"
   echo "Declaring lhapdf v5_8_4 for this flavor"
OS=`uname`
if [ ${OS} = "Darwin" ]
then
   ups declare lhapdf v5_8_4 -r lhapdf/v5_8_4 -2 -m lhapdf.table -q gcc45
else 
   ups declare lhapdf v5_8_4 -r lhapdf/v5_8_4 -4 -m lhapdf.table -q gcc45
fi
setup lhapdf v5_8_4 -q gcc45
echo "lhapdf is installed at ${LHAPDF_FQ_DIR}"

exit 0
